version 9.2

* This file assumes that the file "create correlations.do" has already been run. This puts correlations with Citi into a file called "citicorr.dta" and correlations with BofA into a file called "bofacorr.dta".
* This file assumes that the file "Geithner event study tax.do" has already been run.  This puts abnormal returns into an output file called "Event Study Output tax.dta".


local path "E:\Bank Crisis\"   /*insert local path of the folder used here */
cd "`path'"


* merge in personal connections data

use "Connections Data.dta", clear
gen PERSONAL_CONNECTIONS____________=.
move PERSONAL_CONNECTIONS____________ geithner2num
label var PERSONAL_CONNECTIONS____________ "_____from muckety.com

save "Master Data.dta", replace

* merge in schedule connections data

use "Schedule Data.dta", clear
sort ticker
save "Schedule Data.dta", replace
use "Master Data.dta", clear
sort ticker
merge ticker using "Schedule Data.dta"
drop if _merge==2
drop _merge
gen SCHEDULE_CONNECTIONS____________=.
move SCHEDULE_CONNECTIONS____________ geithnerschednum
label var SCHEDULE_CONNECTIONS____________ "_____from NYT-posted schedule

save "Master Data.dta", replace


* merge in event study results

use "Event Study Output tax.dta", clear
sort ticker
save "Event Study Output tax.dta", replace
use "Master Data.dta", clear
sort ticker
merge ticker using "Event Study Output tax.dta"
drop if _merge==2
drop _merge
gen GEITHNER_ANNC_RETURNS___________=.
move GEITHNER_ANNC_RETURNS___________ index_ds
label var GEITHNER_ANNC_RETURNS___________ "_____from Datastream returns
drop if ret3to4==. /* eliminates firms missing TAQ data */


save "Master Data.dta", replace 


* merge in financial data

use "Financial Data.dta", clear
sort ticker
save "Financial Data.dta", replace
use "Master Data.dta", clear
sort ticker
merge ticker using "Financial Data.dta", update
drop if _merge==2
drop _merge

replace roe2008=. if roe2008>1000   /* eliminate outliers */
replace tdtc2008=. if tdtc2008<0    /* eliminate outliers */
replace ta2008=ta2008*1000          /* puts in $ terms */
replace mcap2008=mcap2008*1000      /* puts in $ terms */
gen ta2008_log=log(ta2008)
move ta2008_log roe2008
label var ta2008_log "log of ta2008
replace roe2008=roe2008/100         /* puts in percentage terms */
replace tdtc2008=tdtc2008/100       /* puts in percentage terms */

gen FINANCIAL_DATA__________________=.
move FINANCIAL_DATA__________________ name
label var FINANCIAL_DATA__________________ "_____from Worldscope

gen ny=0
replace ny=1 if addresscity_ds=="New York"
move ny SCHEDULE_CONNECTIONS____________
label var ny "dummy=1 if addresscity_ds is New York City 



sort ticker
merge ticker using "citicorr.dta"
drop if _merge==2
drop _merge
label variable citicorr "return correlation with Citigroup
label variable citicorr_90th "90th percentile in Citi correlation
sort ticker
merge ticker using "bofacorr.dta"
drop if _merge==2
drop _merge
label variable bofacorr "return correlation with BofA
label variable bofacorr_90th "90th percentile in BofA correlation


* create dummy variables from connections data

gen geithnersched=0
replace geithnersched=1 if geithnerschednum>0 & ~(geithnerschednum==.)
gen geithner2=0
replace geithner2=1 if geithner2num>0 & ~(geithner2num==.)


* calculate actual return day 0 to 3 (for tax event)

gen ret0to3=((1+ret0)*(1+ret1)*(1+ret2)*(1+ret3))-1

* Panel A

ttest ret0 if citicorr<=citicorr_90th & bofacorr<=bofacorr_90th, by(geithnersched)
ttest ret1 if citicorr<=citicorr_90th & bofacorr<=bofacorr_90th, by(geithnersched)
ttest ret2 if citicorr<=citicorr_90th & bofacorr<=bofacorr_90th, by(geithnersched)
ttest ret3 if citicorr<=citicorr_90th & bofacorr<=bofacorr_90th, by(geithnersched)
ttest ret0to3 if citicorr<=citicorr_90th & bofacorr<=bofacorr_90th, by(geithnersched)
ttest ret4 if citicorr<=citicorr_90th & bofacorr<=bofacorr_90th, by(geithnersched)


ttest ret0 if citicorr<=citicorr_90th & bofacorr<=bofacorr_90th, by(geithner2)
ttest ret1 if citicorr<=citicorr_90th & bofacorr<=bofacorr_90th, by(geithner2)
ttest ret2 if citicorr<=citicorr_90th & bofacorr<=bofacorr_90th, by(geithner2)
ttest ret3 if citicorr<=citicorr_90th & bofacorr<=bofacorr_90th, by(geithner2)
ttest ret0to3 if citicorr<=citicorr_90th & bofacorr<=bofacorr_90th, by(geithner2)
ttest ret4 if citicorr<=citicorr_90th & bofacorr<=bofacorr_90th, by(geithner2)


ttest ret0 if citicorr<=citicorr_90th & bofacorr<=bofacorr_90th, by(ny)
ttest ret1 if citicorr<=citicorr_90th & bofacorr<=bofacorr_90th, by(ny)
ttest ret2 if citicorr<=citicorr_90th & bofacorr<=bofacorr_90th, by(ny)
ttest ret3 if citicorr<=citicorr_90th & bofacorr<=bofacorr_90th, by(ny)
ttest ret0to3 if citicorr<=citicorr_90th & bofacorr<=bofacorr_90th, by(ny)
ttest ret4 if citicorr<=citicorr_90th & bofacorr<=bofacorr_90th, by(ny)


* Panel B

ttest abnormal_return0 if citicorr<=citicorr_90th & bofacorr<=bofacorr_90th, by(geithnersched)
ttest CAR0to1 if citicorr<=citicorr_90th & bofacorr<=bofacorr_90th, by(geithnersched)
ttest CAR0to2 if citicorr<=citicorr_90th & bofacorr<=bofacorr_90th, by(geithnersched)
ttest CAR0to3 if citicorr<=citicorr_90th & bofacorr<=bofacorr_90th, by(geithnersched)
ttest CAR0to4 if citicorr<=citicorr_90th & bofacorr<=bofacorr_90th, by(geithnersched)


ttest abnormal_return0 if citicorr<=citicorr_90th & bofacorr<=bofacorr_90th, by(geithner2)
ttest CAR0to1 if citicorr<=citicorr_90th & bofacorr<=bofacorr_90th, by(geithner2)
ttest CAR0to2 if citicorr<=citicorr_90th & bofacorr<=bofacorr_90th, by(geithner2)
ttest CAR0to3 if citicorr<=citicorr_90th & bofacorr<=bofacorr_90th, by(geithner2)
ttest CAR0to4 if citicorr<=citicorr_90th & bofacorr<=bofacorr_90th, by(geithner2)


ttest abnormal_return0 if citicorr<=citicorr_90th & bofacorr<=bofacorr_90th, by(ny)
ttest CAR0to1 if citicorr<=citicorr_90th & bofacorr<=bofacorr_90th, by(ny)
ttest CAR0to2 if citicorr<=citicorr_90th & bofacorr<=bofacorr_90th, by(ny)
ttest CAR0to3 if citicorr<=citicorr_90th & bofacorr<=bofacorr_90th, by(ny)
ttest CAR0to4 if citicorr<=citicorr_90th & bofacorr<=bofacorr_90th, by(ny)


* Panel C

ttest ret0, by(geithnersched)
ttest ret1, by(geithnersched)
ttest ret2, by(geithnersched)
ttest ret3, by(geithnersched)
ttest ret0to3, by(geithnersched)
ttest ret4, by(geithnersched)


ttest ret0, by(geithner2)
ttest ret1, by(geithner2)
ttest ret2, by(geithner2)
ttest ret3, by(geithner2)
ttest ret0to3, by(geithner2)
ttest ret4, by(geithner2)


ttest ret0, by(ny)
ttest ret1, by(ny)
ttest ret2, by(ny)
ttest ret3, by(ny)
ttest ret0to3, by(ny)
ttest ret4, by(ny)


* Panel D

ttest abnormal_return0, by(geithnersched)
ttest CAR0to1, by(geithnersched)
ttest CAR0to2, by(geithnersched)
ttest CAR0to3, by(geithnersched)
ttest CAR0to4, by(geithnersched)


ttest abnormal_return0, by(geithner2)
ttest CAR0to1, by(geithner2)
ttest CAR0to2, by(geithner2)
ttest CAR0to3, by(geithner2)
ttest CAR0to4, by(geithner2)


ttest abnormal_return0, by(ny)
ttest CAR0to1, by(ny)
ttest CAR0to2, by(ny)
ttest CAR0to3, by(ny)
ttest CAR0to4, by(ny)


drop geithnersched geithner2 ret0to3
erase "Master Data.dta"
