version 9.2

* This file assumes that the file "create correlations.do" has already been run. This puts correlations with Citi into an output file called "citicorr.dta".
* This file assumes that the file "Geithner event study.do" has already been run.  This puts abnormal returns into an output file called "Event Study Output.dta".


local path "E:\Bank Crisis\"   /*insert local path of the folder used here */
cd "`path'"

* merge in personal connections data

use "Connections Data.dta", clear
gen PERSONAL_CONNECTIONS____________=.
move PERSONAL_CONNECTIONS____________ geithner2num
label var PERSONAL_CONNECTIONS____________ "_____from muckety.com

save "Master Data.dta", replace


* merge in schedule connections data

use "Schedule Data.dta", clear
sort ticker
save "Schedule Data.dta", replace
use "Master Data.dta", clear
sort ticker
merge ticker using "Schedule Data.dta"
drop if _merge==2
drop _merge
gen SCHEDULE_CONNECTIONS____________=.
move SCHEDULE_CONNECTIONS____________ geithnerschednum
label var SCHEDULE_CONNECTIONS____________ "_____from NYT-posted schedule

save "Master Data.dta", replace


* merge in event study results

use "Event Study Output.dta", clear
sort ticker
save "Event Study Output.dta", replace
use "Master Data.dta", clear
sort ticker
merge ticker using "Event Study Output.dta"
drop if _merge==2
drop _merge
gen GEITHNER_ANNC_RETURNS___________=.
move GEITHNER_ANNC_RETURNS___________ index_ds
label var GEITHNER_ANNC_RETURNS___________ "_____from Datastream returns

drop if ret0==. /* eliminates firms missing TAQ data */

save "Master Data.dta", replace 


* merge in financial data

use "Financial Data.dta", clear
sort ticker
save "Financial Data.dta", replace
use "Master Data.dta", clear
sort ticker
merge ticker using "Financial Data.dta", update
drop if _merge==2
drop _merge

replace roe2008=. if roe2008>1000   /* eliminate outliers */
replace tdtc2008=. if tdtc2008<0    /* eliminate outliers */
replace ta2008=ta2008*1000          /* puts in $ terms */
replace mcap2008=mcap2008*1000      /* puts in $ terms */
gen ta2008_log=log(ta2008)
move ta2008_log roe2008
label var ta2008_log "log of ta2008
replace roe2008=roe2008/100         /* puts in percentage terms */
replace tdtc2008=tdtc2008/100       /* puts in percentage terms */

gen FINANCIAL_DATA__________________=.
move FINANCIAL_DATA__________________ name
label var FINANCIAL_DATA__________________ "_____from Worldscope

gen ny=0
replace ny=1 if addresscity_ds=="New York"
move ny SCHEDULE_CONNECTIONS____________
label var ny "dummy=1 if addresscity_ds is New York City


sort ticker
merge ticker using "citicorr.dta"
drop if _merge==2
drop _merge
label variable citicorr "return correlation with Citigroup
label variable citicorr_90th "90th percentile in Citi correlation

sort ticker
merge ticker using "residuals ttest.dta"
drop if _merge==2
drop _merge

sort ticker
merge ticker using "residuals ttest raw.dta"
drop if _merge==2
drop _merge

* Create dummy variables from connections data

gen geithnersched=0
replace geithnersched=1 if geithnerschednum>0 & ~(geithnerschednum==.)
gen geithner2=0
replace geithner2=1 if geithner2num>0 & ~(geithner2num==.)


* Calculate actual return for days 0 through 10

gen ret0to10=((1+ret0)*(1+ret1)*(1+ret2)*(1+ret3)*(1+ret4)*(1+ret5)*(1+ret6)*(1+ret7)*(1+ret8)*(1+ret9)*(1+ret10))-1



*  Panel A
gen constant=1
ttest ret0 , by(geithnersched)
putmata Y=ret0 X=(geithnersched constant) Err=(residbaseoneraw*), omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end
ttest ret1 , by(geithnersched)
putmata Y=ret1 X=(geithnersched constant) Err=(residbaseoneraw*), omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end
ttest ret2 , by(geithnersched)
putmata Y=ret2 X=(geithnersched constant) Err=(residbaseoneraw*), omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end
ttest ret3 , by(geithnersched)
putmata Y=ret3 X=(geithnersched constant) Err=(residbaseoneraw*), omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end
ttest ret4 , by(geithnersched)
putmata Y=ret4 X=(geithnersched constant) Err=(residbaseoneraw*), omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end
ttest ret5 , by(geithnersched)
putmata Y=ret5 X=(geithnersched constant) Err=(residbaseoneraw*), omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end
ttest ret6 , by(geithnersched)
putmata Y=ret6 X=(geithnersched constant) Err=(residbaseoneraw*), omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end
ttest ret7 , by(geithnersched)
putmata Y=ret7 X=(geithnersched constant) Err=(residbaseoneraw*), omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end
ttest ret8 , by(geithnersched)
putmata Y=ret8 X=(geithnersched constant) Err=(residbaseoneraw*), omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end
ttest ret9 , by(geithnersched)
putmata Y=ret9 X=(geithnersched constant) Err=(residbaseoneraw*), omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end
ttest ret10 , by(geithnersched)
putmata Y=ret10 X=(geithnersched constant) Err=(residbaseoneraw*), omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end
ttest ret0to10 , by(geithnersched)
putmata Y=ret0to10 X=(geithnersched constant) Err=(residbasetenraw*), omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end

ttest ret0 , by(geithner2)
putmata Y=ret0 X=(geithner2 constant) Err=(residbaseoneraw*), omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end
ttest ret1 , by(geithner2)
putmata Y=ret1 X=(geithner2 constant) Err=(residbaseoneraw*), omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end
ttest ret2 , by(geithner2)
putmata Y=ret2 X=(geithner2 constant) Err=(residbaseoneraw*), omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end
ttest ret3 , by(geithner2)
putmata Y=ret3 X=(geithner2 constant) Err=(residbaseoneraw*), omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end
ttest ret4 , by(geithner2)
putmata Y=ret4 X=(geithner2 constant) Err=(residbaseoneraw*), omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end
ttest ret5 , by(geithner2)
putmata Y=ret5 X=(geithner2 constant) Err=(residbaseoneraw*), omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end
ttest ret6 , by(geithner2)
putmata Y=ret6 X=(geithner2 constant) Err=(residbaseoneraw*), omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end
ttest ret7 , by(geithner2)
putmata Y=ret7 X=(geithner2 constant) Err=(residbaseoneraw*), omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end
ttest ret8 , by(geithner2)
putmata Y=ret8 X=(geithner2 constant) Err=(residbaseoneraw*), omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end
ttest ret9 , by(geithner2)
putmata Y=ret9 X=(geithner2 constant) Err=(residbaseoneraw*), omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end
ttest ret10 , by(geithner2)
putmata Y=ret10 X=(geithner2 constant) Err=(residbaseoneraw*), omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end
ttest ret0to10 , by(geithner2)
putmata Y=ret0to10 X=(geithner2 constant) Err=(residbasetenraw*), omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end

ttest ret0 , by(ny)
putmata Y=ret0 X=(ny constant) Err=(residbaseoneraw*), omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end
ttest ret1 , by(ny)
putmata Y=ret1 X=(ny constant) Err=(residbaseoneraw*), omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end
ttest ret2 , by(ny)
putmata Y=ret2 X=(ny constant) Err=(residbaseoneraw*), omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end
ttest ret3 , by(ny)
putmata Y=ret3 X=(ny constant) Err=(residbaseoneraw*), omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end
ttest ret4 , by(ny)
putmata Y=ret4 X=(ny constant) Err=(residbaseoneraw*), omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end
ttest ret5 , by(ny)
putmata Y=ret5 X=(ny constant) Err=(residbaseoneraw*), omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end
ttest ret6 , by(ny)
putmata Y=ret6 X=(ny constant) Err=(residbaseoneraw*), omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end
ttest ret7 , by(ny)
putmata Y=ret7 X=(ny constant) Err=(residbaseoneraw*), omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end
ttest ret8 , by(ny)
putmata Y=ret8 X=(ny constant) Err=(residbaseoneraw*), omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end
ttest ret9 , by(ny)
putmata Y=ret9 X=(ny constant) Err=(residbaseoneraw*), omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end
ttest ret10 , by(ny)
putmata Y=ret10 X=(ny constant) Err=(residbaseoneraw*), omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end
ttest ret0to10 , by(ny)
putmata Y=ret0to10 X=(ny constant) Err=(residbasetenraw*), omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end

* Panel B

ttest abnormal_return0 , by(geithnersched)
putmata Y=abnormal_return0 X=(geithnersched constant) Err=(residbaseone*), omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end
ttest CAR0to1 , by(geithnersched)
putmata Y=CAR0to1 X=(geithnersched constant) Err=(residbasetwo*), omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end
ttest CAR0to2 , by(geithnersched)
putmata Y=CAR0to2 X=(geithnersched constant) Err=(residbasethree*), omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end
ttest CAR0to3 , by(geithnersched)
putmata Y=CAR0to3 X=(geithnersched constant) Err=(residbasefour*), omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end
ttest CAR0to4 , by(geithnersched)
putmata Y=CAR0to4 X=(geithnersched constant) Err=(residbasefive*), omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end
ttest CAR0to5 , by(geithnersched)
putmata Y=CAR0to5 X=(geithnersched constant) Err=(residbasesix*), omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end
ttest CAR0to6 , by(geithnersched)
putmata Y=CAR0to6 X=(geithnersched constant) Err=(residbaseseven*), omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end
ttest CAR0to7 , by(geithnersched)
putmata Y=CAR0to7 X=(geithnersched constant) Err=(residbaseeight*), omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end
ttest CAR0to8 , by(geithnersched)
putmata Y=CAR0to8 X=(geithnersched constant) Err=(residbasenine*), omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end
ttest CAR0to9 , by(geithnersched)
putmata Y=CAR0to9 X=(geithnersched constant) Err=(residbaseten*), omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end
ttest CAR0to10 , by(geithnersched)
putmata Y=CAR0to10 X=(geithnersched constant) Err=(residbaseeleven*), omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end





ttest abnormal_return0 , by(geithner2)
putmata Y=abnormal_return0 X=(geithner2 constant) Err=(residbaseone*), omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end
ttest CAR0to1 , by(geithner2)
putmata Y=CAR0to1 X=(geithner2 constant) Err=(residbasetwo*), omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end
ttest CAR0to2 , by(geithner2)
putmata Y=CAR0to2 X=(geithner2 constant) Err=(residbasethree*), omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end
ttest CAR0to3 , by(geithner2)
putmata Y=CAR0to3 X=(geithner2 constant) Err=(residbasefour*), omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end
ttest CAR0to4 , by(geithner2)
putmata Y=CAR0to4 X=(geithner2 constant) Err=(residbasefive*), omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end
ttest CAR0to5 , by(geithner2)
putmata Y=CAR0to5 X=(geithner2 constant) Err=(residbasesix*), omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end
ttest CAR0to6 , by(geithner2)
putmata Y=CAR0to6 X=(geithner2 constant) Err=(residbaseseven*), omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end
ttest CAR0to7 , by(geithner2)
putmata Y=CAR0to7 X=(geithner2 constant) Err=(residbaseeight*), omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end
ttest CAR0to8 , by(geithner2)
putmata Y=CAR0to8 X=(geithner2 constant) Err=(residbasenine*), omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end
ttest CAR0to9 , by(geithner2)
putmata Y=CAR0to9 X=(geithner2 constant) Err=(residbaseten*), omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end
ttest CAR0to10 , by(geithner2)
putmata Y=CAR0to10 X=(geithner2 constant) Err=(residbaseeleven*), omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end





ttest abnormal_return0 , by(ny)
putmata Y=abnormal_return0 X=(ny constant) Err=(residbaseone*), omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end
ttest CAR0to1 , by(ny)
putmata Y=CAR0to1 X=(ny constant) Err=(residbasetwo*), omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end
ttest CAR0to2 , by(ny)
putmata Y=CAR0to2 X=(ny constant) Err=(residbasethree*), omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end
ttest CAR0to3 , by(ny)
putmata Y=CAR0to3 X=(ny constant) Err=(residbasefour*), omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end
ttest CAR0to4 , by(ny)
putmata Y=CAR0to4 X=(ny constant) Err=(residbasefive*), omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end
ttest CAR0to5 , by(ny)
putmata Y=CAR0to5 X=(ny constant) Err=(residbasesix*), omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end
ttest CAR0to6 , by(ny)
putmata Y=CAR0to6 X=(ny constant) Err=(residbaseseven*), omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end
ttest CAR0to7 , by(ny)
putmata Y=CAR0to7 X=(ny constant) Err=(residbaseeight*), omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end
ttest CAR0to8 , by(ny)
putmata Y=CAR0to8 X=(ny constant) Err=(residbasenine*), omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end
ttest CAR0to9 , by(ny)
putmata Y=CAR0to9 X=(ny constant) Err=(residbaseten*), omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end
ttest CAR0to10 , by(ny)
putmata Y=CAR0to10 X=(ny constant) Err=(residbaseeleven*), omitmissing replace
mata
b=invsym(X'X)*(X'Y)
e=Y-X*b
n=rows(X)
k=cols(X)
s2=(e'e)/(n-k)
V=s2*invsym(X'X)
se=sqrt(diagonal(V))
sigma=variance(Err')
V_adj=invsym(X'X)*(X'*sigma*X)* invsym(X'X)
se_adj=sqrt(diagonal(V_adj))
(b, se, b:/se, se_adj, b:/se_adj)
(n)
end



drop geithnersched geithner2 ret0to10
erase "Master Data.dta"
