version 9.2
* This file assumes that the file "Geithner event study.do" has already been run.  This puts abnormal returns into an output file called "Event Study Output.dta".

* This file creates the return correlation of each sample firm with Citigroup and Bank of America.
* Output goes into files called citicorr.dta and bofacorr.dta


local path "E:\Bank Crisis\"   /*insert local path of the folder used here */
cd "`path'"


/* Calculate correlation of each firm with Citigroup */

use "Return Data.dta", clear

set more off

reshape long ri, i(index) j(day) string

gen statadate=date(day,"dm20y")

/* drop stock market holidays, below are Jul07 to Feb09*/
drop if statadate==17351 |statadate==17412 |statadate==17492 |statadate==17525 |statadate==17532 |statadate==17552 | statadate==17580 |statadate==17612 | statadate==17678 | statadate==17717 | statadate==17776 | statadate==17863 | statadate==17891 | statadate==17898 | statadate==17916 | statadate==17944 
sort index statadate
by index: gen ret=(ri-ri[_n-1])/ri[_n-1]
drop if statadate<17454 | statadate>17814  /* 250-day estimation window */
save "temp.dta", replace
drop if ~(ticker=="C")
gen citiret=ret
sort statadate
save "merge.dta", replace
use "temp.dta", clear
sort statadate
merge statadate using "merge.dta"
drop _merge
gen citicorr=.
egen id=group(index)

forvalues i=1(1)678 {
 quietly corr ret citiret if id==`i'
 quietly replace citicorr=r(rho) if id==`i'
}
drop id
sort ticker
save "citicorr.dta", replace


/* merge in financial data */

use "Financial Data.dta", clear
sort ticker
save "Financial Data.dta", replace
use "citicorr.dta", clear
sort ticker
merge ticker using "Financial Data.dta", update
drop if _merge==2
drop _merge

replace roe2008=. if roe2008>1000   /* eliminate outliers */
replace tdtc2008=. if tdtc2008<0    /* eliminate outliers */
gen ta2008_log=log(ta2008)


drop if ~(fullsample==1)
collapse citicorr, by(ticker)
egen citicorr_90th=pctile(citicorr), p(90)
egen citicorr_92th=pctile(citicorr), p(92)
egen citicorr_94th=pctile(citicorr), p(94)
egen citicorr_96th=pctile(citicorr), p(96)
egen citicorr_98th=pctile(citicorr), p(98)
egen citicorr_99th=pctile(citicorr), p(99)

sort ticker

save "citicorr.dta", replace


/* Calculate correlation of each firm with B of A */

use "Return Data.dta", clear

set more off

reshape long ri, i(index) j(day) string

gen statadate=date(day,"dm20y")
/* drop stock market holidays, below are Jul07 to Feb09*/
drop if statadate==17351 |statadate==17412 |statadate==17492 |statadate==17525 |statadate==17532 |statadate==17552 | statadate==17580 |statadate==17612 | statadate==17678 | statadate==17717 | statadate==17776 | statadate==17863 | statadate==17891 | statadate==17898 | statadate==17916 | statadate==17944 
sort index statadate
by index: gen ret=(ri-ri[_n-1])/ri[_n-1]
drop if statadate<17454 | statadate>17814  /* 250-day estimation window */
save "temp.dta", replace
drop if ~(ticker=="BAC")
gen bofaret=ret
sort statadate
save "merge.dta", replace
use "temp.dta", clear
sort statadate
merge statadate using "merge.dta"
drop _merge
gen bofacorr=.
egen id=group(index)

forvalues i=1(1)678 {
 quietly corr ret bofaret if id==`i'
 quietly replace bofacorr=r(rho) if id==`i'
}
drop id
sort ticker
save "bofacorr.dta", replace

/* merge in event study results */

use "Event Study Output.dta", clear
sort ticker
save "Event Study Output.dta", replace
use "bofacorr.dta", clear
sort ticker
merge ticker using "Event Study Output.dta"
drop if _merge==2
drop _merge

drop if ret0==. /* this excludes firms that are missing TAQ data */

save "bofacorr.dta", replace 


/* merge in financial data */

use "Financial Data.dta", clear
sort ticker
save "Financial Data.dta", replace
use "bofacorr.dta", clear
sort ticker
merge ticker using "Financial Data.dta", update
drop if _merge==2
drop _merge

replace roe2008=. if roe2008>1000   /* eliminate outliers */
replace tdtc2008=. if tdtc2008<0    /* eliminate outliers */
gen ta2008_log=log(ta2008)


drop if CAR0to1==. | ta2008_log==. | roe2008==. | tdtc2008==.
drop if ~(fullsample==1)
collapse bofacorr, by(ticker)
egen bofacorr_90th=pctile(bofacorr), p(90)
sort ticker
save "bofacorr.dta", replace

erase "temp.dta" 
erase "merge.dta"
